@@ -1020,13 +1020,11 @@ loosing basic functionality when using `vm-mime-auto-save-all-attachments'."
 ;  (vm-mime-display-internal-text/plain layout))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-(defcustom vm-mime-all-attachments-directory
-  (if (boundp 'vm-mime-attachment-save-directory)
-      vm-mime-attachment-save-directory
-    (expand-file-name "~/Attachments"))
+(defcustom vm-mime-all-attachments-directory nil
     "*Directory to where the attachments should go or come from."
  :group 'vm-rfaddons
- :type 'directory)
+ :type '(choice (directory :tag "Directory:")
+                (const :tag "Use `vm-mime-attachment-save-directory'" nil)))
 
 (defvar vm-mime-save-all-attachments-history nil
   "Directory history to where the attachments should go.")
@@ -1535,7 +1533,7 @@ headers."
   :type '(regexp))
 
 (defcustom vm-mime-encode-headers-words-regexp
-  (let ((8bit-word "\\([^ \t\n\r]*[^\x0-\x80]+[^ \t\n\r]*\\)+"))
+  (let ((8bit-word "\\([^ \t\n\r]*[^\x0-\x7f]+[^ \t\n\r]*\\)+"))
     (concat "\\s-\\(" 8bit-word "\\(\\s-+" 8bit-word "\\)*\\)"))
   "*A regexp matching a set of consecutive words which must be encoded."
   :group 'vm-rfaddons
@@ -1572,7 +1570,9 @@ should be encoded together."
                            bodysep)
                   hend  (vm-marker hend)))
           ;; search for words containing chars in the upper 8bit range
-          (while (re-search-forward vm-mime-encode-headers-words-regexp hend t)
+          (while
+	      (let ((case-fold-search nil))
+		(re-search-forward vm-mime-encode-headers-words-regexp hend t))
             (setq start (match-beginning 1)
                   end   (vm-marker (match-end 1))
                   charset (or (vm-determine-proper-charset start end)
